@@ -50,7 +50,7 @@ class MatrixInviterForm(SettingsForm):
     )
     matrix_inviter_matrix_room = RegexField(
         label=_("Matrix room"),
-        regex="(!|#)[^:]+:.+",
+        regex="(?:!|#)[^:]+:[^:,]+(?:\\s*,\\s*(?:!|#)[^:]+:[^:,]+)*",
         strip=True,
     )
 
@@ -61,22 +61,32 @@ class MatrixInviterForm(SettingsForm):
         ]
 
         room_info = matrix_room_info_for_event(self.obj)
-        if not room_info["room_id"]:
-            room_help_text = ""
-        elif self.obj.settings.matrix_inviter_matrix_room.startswith("!"):
-            if room_info["canonical_alias"]:
-                room_help_text = _(
-                    '"{name}" (main address: <code>{canonical_alias}</code>)'
-                )
-            else:
-                room_help_text = _('"{name}"')
+        if not room_info:
+            room_help_text = _(
+                "Comma-separated list of room IDs or aliases to invite users to."
+            )
         else:
-            if room_info["canonical_alias"]:
-                room_help_text = _(
-                    '"{name}" (<code>{room_id}</code>, main address: <code>{canonical_alias}</code>)'
-                )
-            else:
-                room_help_text = _('"{name}" (<code>{room_id}</code>)')
-        self.fields["matrix_inviter_matrix_room"].help_text = room_help_text.format_map(
-            room_info
-        )
+            room_help = []
+            for room in room_info:
+                if room["room_id"].startswith("!"):
+                    if room["canonical_alias"]:
+                        room_help.append(
+                            _(
+                                '"{name}" (main address: <code>{canonical_alias}</code>)'
+                            ).format_map(room)
+                        )
+                    else:
+                        room_help.append(_('"{name}"').format_map(room))
+                else:
+                    if room["canonical_alias"]:
+                        room_help.append(
+                            _(
+                                '"{name}" (<code>{room_id}</code>, main address: <code>{canonical_alias}</code>)'
+                            ).format_map(room)
+                        )
+                    else:
+                        room_help.append(
+                            _('"{name}" (<code>{room_id}</code>)').format_map(room)
+                        )
+            room_help_text = ", ".join(room_help)
+        self.fields["matrix_inviter_matrix_room"].help_text = room_help_text
