@@ -2,14 +2,23 @@ import requests
 from urllib.parse import quote as url_quote
 
 
+def matrix_parse_room_ids(room_ids):
+    return [room_id.strip() for room_id in room_ids.split(",")]
+
+
 def matrix_room_info_for_event(event):
     return event.cache.get_or_set(
         "matrix_room_info",
-        matrix_room_info(
-            event.settings.matrix_inviter_matrix_server,
-            event.settings.matrix_inviter_authorization_token,
-            event.settings.matrix_inviter_matrix_room,
-        ),
+        [
+            matrix_room_info(
+                event.settings.matrix_inviter_matrix_server,
+                event.settings.matrix_inviter_authorization_token,
+                room_id,
+            )
+            for room_id in matrix_parse_room_ids(
+                event.settings.matrix_inviter_matrix_room
+            )
+        ],
         120,
     )
 
