@@ -19,7 +19,12 @@ logger = logging.getLogger(__name__)
     retry_backoff_max=3600,
 )
 def matrix_inviter_invite(
-    self, event: int, order: int, order_position: int, invitation_reason: str
+    self,
+    event: int,
+    order: int,
+    order_position: int,
+    invitation_reason: str,
+    room_id: str,
 ):
     order_position = OrderPosition.objects.get(pk=order_position)
 
@@ -30,10 +35,13 @@ def matrix_inviter_invite(
     if not user_matrix_id:
         return
 
+    if not room_id:
+        return
+
     order = Order.objects.get(pk=order)
     server = event.settings.matrix_inviter_matrix_server
     token = event.settings.matrix_inviter_authorization_token
-    room_id = matrix_room_id(server, event.settings.matrix_inviter_matrix_room)
+    room_id = matrix_room_id(server, room_id)
     payload = {"user_id": user_matrix_id}
     if invitation_reason:
         payload["reason"] = invitation_reason
@@ -96,7 +104,9 @@ def matrix_inviter_invite(
     retry_backoff=True,
     retry_backoff_max=3600,
 )
-def matrix_inviter_kick(self, event: int, order: int, order_position: int):
+def matrix_inviter_kick(
+    self, event: int, order: int, order_position: int, room_id: str
+):
     order_position = OrderPosition.objects.get(pk=order_position)
 
     user_matrix_id = order_position.meta_info_data.get("question_form_data", {}).get(
@@ -106,10 +116,13 @@ def matrix_inviter_kick(self, event: int, order: int, order_position: int):
     if not user_matrix_id:
         return
 
+    if not room_id:
+        return
+
     order = Order.objects.get(pk=order)
     server = event.settings.matrix_inviter_matrix_server
     token = event.settings.matrix_inviter_authorization_token
-    room_id = matrix_room_id(server, event.settings.matrix_inviter_matrix_room)
+    room_id = matrix_room_id(server, room_id)
     payload = {"user_id": user_matrix_id}
 
     try:
